/***************************************************************************
 *            main-callbacks.c
 *
 *  Sat Jul  9 16:28:05 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "main-callbacks.h"
#include "interface.h"
#include "support.h"
#include "gui-fun.h"
#include "db-fun.h"
#include "settings-fun.h"
#include "book-fun.h"
#include "men_db-fun.h"


void
on_main_win_show                       (GtkWidget       *widget,
                                        gpointer         user_data)
{
	main_window = widget;
	set_statusbar_text (_("Loading data base, please wait..."));
	get_current_date ();
	open_db ();
	if (load_settings_file ())	{
		/*	Ladujemy ustawienia		*/
		load_main_win_position ();
		make_security_copy ();
		set_statusbar_text (_("GBiblioteka is ready to work!"));
	}
	else	{
		set_statusbar_text (_("GBiblioteka sterted with errors!"));
	}
	create_main_view ();
	set_widget_sensinitive (widget, "rem_book_but", FALSE);
	set_widget_sensinitive (widget, "edit_book_but", FALSE);
	set_widget_sensinitive (widget, "export_data", FALSE);
	set_widget_sensinitive (widget, "backup_data", FALSE);
	set_widget_sensinitive (widget, "lend_book_togbut", FALSE);
	load_books_titles ();
}

gboolean
on_main_win_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	close_db ();
	save_settings ();
	gtk_main_quit ();
	return FALSE;
}


void
on_add_book_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	
	save_mode = 1;
	widget = (gpointer) create_add_book_dlg ();
	create_add_dlg_data (widget);
	gtk_widget_show (widget);
}


void
on_export_data_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*dialog;
	dialog = create_export_database_dlg ();
	gtk_widget_show (dialog);
	export_data_from_db (dialog);
}


void
on_backup_data_activate                (GtkMenuItem     *menuitem,
                                        gpointer		user_data)
{
	GtkWidget	*widget;
	gint		result;
	widget = create_backup_database_dlg ();
	
	result = gtk_dialog_run (GTK_DIALOG (widget));
	
	switch (result)	{
		case GTK_RESPONSE_DELETE_EVENT:
			gtk_widget_destroy (widget);
			break;
		case GTK_RESPONSE_CLOSE:
			gtk_widget_destroy (widget);
			break;
		default:
			gtk_widget_destroy (widget);
	}
}


void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	close_db ();
	save_settings ();
	gtk_main_quit ();
}


void
on_search_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	show_message_dlg (_("Development release"), "Not implemeted yet!", 1);
}

void
on_edit_authors_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	men_db_mode = 1;
	widget = (gpointer) create_men_db_data_type ();
	create_men_db_view (widget);
	load_authors (widget);
	gtk_widget_show (widget);
	
	clear_book_display ();
}

void
on_edit_genere_base_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	men_db_mode = 2;
	widget = (gpointer) create_men_db_data_type ();
	create_men_db_view (widget);
	load_authors (widget);
	gtk_widget_show (widget);
	
	clear_book_display ();
}

void
on_edit_pub_houses_base_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	men_db_mode = 3;
	widget = (gpointer) create_men_db_data_type ();
	create_men_db_view (widget);
	load_authors (widget);
	gtk_widget_show (widget);
	
	clear_book_display ();	
}


void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *widget;
	widget = (gpointer) create_about_dlg ();
	gtk_widget_show (widget);
}

void
on_settings_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	gint		result;
	widget = (gpointer) create_settings_dlg ();
	
	load_settings_dlg (widget);
	result = gtk_dialog_run (GTK_DIALOG (widget));
	
	switch (result)	{
		case GTK_RESPONSE_DELETE_EVENT:
			gtk_widget_destroy (widget);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy (widget);
			break;
		case GTK_RESPONSE_OK:
			get_settings_from_dlg (widget);
			save_settings ();
			gtk_widget_destroy (widget);
			break;
		default:
			gtk_widget_destroy (widget);
	}
}

void
on_main_add_tbut_clicked               (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	
	save_mode = 1;
	widget = (gpointer) create_add_book_dlg ();
	create_add_dlg_data (widget);
	gtk_widget_show (widget);
}


void
on_main_exit_tbut_clicked              (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	close_db ();
	save_settings ();
	gtk_main_quit ();
}


void
on_main_search_tbut_clicked            (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	show_message_dlg (_("Development release"), "Not implemeted yet!", 1);
}

void
on_lend_book_togbut_clicked            (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))	{
		book.lended = 1;
	}
	else	{
		book.lended = 0;
	}
	save_mode = 3;
	save_book ();
	reload_main_view ();
}

void
on_edit_book_but_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	
	save_mode = 2;
	widget = (gpointer) create_add_book_dlg ();
	
	create_add_dlg_data (widget);
	load_data_into_add_book_dlg (widget);
	
	gtk_widget_show (widget);
}


void
on_rem_book_but_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	gint		result;
	widget = (gpointer) create_rem_book_dlg ();
	
	result = gtk_dialog_run (GTK_DIALOG (widget));
	
	switch (result)	{
		case GTK_RESPONSE_DELETE_EVENT:
			gtk_widget_destroy (widget);
			break;
		case GTK_RESPONSE_NO:
			gtk_widget_destroy (widget);
			break;
		case GTK_RESPONSE_YES:
			remove_book (book.id);
			clear_book_display ();
			reload_main_view ();
			gtk_widget_destroy (widget);
			break;
		default:
			gtk_widget_destroy (widget);
	}
}

void
on_main_tview_cursor_changed           (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	guint				book_id;
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &book_id, -1);
	clear_book_display ();
	select_book_data (book_id);
	display_book_data ();
	
	set_widget_sensinitive (GTK_WIDGET (treeview), "edit_book_but", TRUE);
	set_widget_sensinitive (GTK_WIDGET (treeview), "rem_book_but", TRUE);
	set_widget_sensinitive (GTK_WIDGET (treeview), "lend_book_togbut", TRUE);
}
