/***************************************************************************
 *            other-callbacks.c
 *
 *  Sun Jul 10 13:26:11 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "other-callbacks.h"
#include "support.h"
#include "book-fun.h"
#include "utility-fun.h"
#include "db-fun.h"
#include "gui-fun.h"
#include "settings-fun.h"
#include "men_db-fun.h"


/*
 *	Funkcje zwrotne okna wlasciwosci 'add_book_dlg'
 */

void
on_add_book_cancel_but_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "add_book_dlg");
	gtk_widget_destroy (widget);
}

void
on_add_book_ok_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "add_book_dlg");
	
	if (check_book_data (widget))	{
		update_book_data_from_dlg (widget);
		save_book ();
		clear_book_display ();
		reload_main_view ();
		gtk_widget_destroy (widget);
	}										
}

/*
 *	Funkcje zwrotne okna wlasciwosci 'settings_dlg'
 */

void
on_set_auto_copy_chbox_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))	{
		set_widget_sensinitive (GTK_WIDGET(button), "sec_lb_fir", TRUE);
		set_widget_sensinitive (GTK_WIDGET(button), "security_month_spin", TRUE);
		set_widget_sensinitive (GTK_WIDGET(button), "sec_lb_sec", TRUE);
	}
	else	{
		set_widget_sensinitive (GTK_WIDGET(button), "sec_lb_fir", FALSE);
		set_widget_sensinitive (GTK_WIDGET(button), "security_month_spin", FALSE);
		set_widget_sensinitive (GTK_WIDGET(button), "sec_lb_sec", FALSE);
	}
}

void
on_security_month_spin_changed         (GtkEditable     *editable,
                                        gpointer         user_data)
{
	get_settings_from_dlg (GTK_WIDGET (editable));
	settings.next_copy_month = month + settings.frequency;
	if (settings.next_copy_month > 12)
		settings.next_copy_month = settings.next_copy_month - 12;
}

/*
 *	Funkcje zwrotne okien 'export_database_dlg' i 'backup_database_dlg'
 */

void
on_export_close_but_clicked            (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "export_database_dlg");
	gtk_widget_destroy (widget);
}

void
on_backup_but_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
	backup_database (GTK_WIDGET (button));
}

/*
 *	Funkcje zwrotne okien 'men_db_dlg' i 'men_db_rem_dlg'
 */

void
on_men_db_tview_cursor_changed         (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &selected_item_id, -1);
	
	set_widget_sensinitive (GTK_WIDGET (treeview), "men_db_add_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (treeview), "men_db_rem_but", TRUE);
}

void
on_men_db_rem_but_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	men_db_lookup_widget = GTK_WIDGET (button);
	check_if_item_used ();
}

void
on_men_db_add_but_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	add_item_to_database (GTK_WIDGET (button));
	reload_men_db_view (GTK_WIDGET (button));
}

void
on_menage_db_close_but_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "menage_db_dlg");
	gtk_widget_destroy (widget);
	
	men_db_mode = 0;
}


void
on_men_db_en_changed                   (GtkEditable     *editable,
                                        gpointer         user_data)
{
	if (strlen (gtk_entry_get_text (GTK_ENTRY (editable))) == 0)	{
		set_widget_sensinitive (GTK_WIDGET (editable), "men_db_add_but", FALSE);
	}
	else	{
		set_widget_sensinitive (GTK_WIDGET (editable), "men_db_add_but", TRUE);
	}
	
	set_widget_sensinitive (GTK_WIDGET (editable), "men_db_rem_but", FALSE);
}

void
on_men_db_rem_no_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "men_db_rem_dlg");
	gtk_widget_destroy (widget);
}

void
on_men_db_rem_yes_but_clicked          (GtkButton       *button,
                                        gpointer         user_data)
{
	update_table_book (GTK_WIDGET (button));
	rem_item_from_database ();
}

void
on_men_db_rem_close_but_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	widget = (gpointer) lookup_widget (GTK_WIDGET (button), "men_db_rem_dlg");
	
	reload_men_db_view (men_db_lookup_widget);
	gtk_widget_destroy (widget);
}
